#!/bin/awk -f

#############################################################################
# Post-processor for SASweave - cleans-up SAS .lst file to make a .tex file
# Copyright (C) 2006 Russell V. Lenth - University of Iowa
# Revised: 2007.06.04
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
##############################################################################

function TOFmsg () {
  print "%%% Generated by sasweave (R Lenth, Dec., 2006)\n" > texfile
}

BEGIN {
  print "Creating .tex file ..."
  sasoutput = 0
  squeeze = 1
  infile = ARGV[1]
  dot = index(infile,".lst")
  texfile = substr(infile,1,dot) "tex"
  maintexfile = texfile
  TOFmsg()
  getline  ### Strip "The SAS System" message from the beginning
  getline
}

/^-----SASweaveDIVERT/ {
  texfile = $2
  TOFmsg()
  getline
}

/^-----SASweaveSQUEEZE/ {
  squeeze = $2
  getline
  while ($0 == "") getline # Gobble-up any blank lines
}

/\\begin{SASoutput}/ {
  sasoutput = 1
  pending = $0   # Hold on to this line - we may not want to output it
  next
}

/\f/ { # Cut out formfeeds and the line after
  getline
  next
}

/\\end{SASoutput}/ {
  sasoutput = 0
  if (pending) {  # if so, we have an empty SASoutput env
    getline
    pending = ""
  }
}

/^-----SASweaveREVERT/ {
  texfile = maintexfile
  getline
}

$0=="" && squeeze && sasoutput==1 {   # reduce # of blank lines in SAS output
  getline
}

/\\begin{SASinput}/ {
  pending = $0   # Hold on to this line - we may not want to output it
  next
}

/\\end{SASinput}/ {
  if (pending) {  # if so, we have an empty SASinput env
    getline
    pending = ""
  }
}

{
  if (pending) {   # print pending line first
    print pending >> texfile
    pending = ""
  }
  print >> texfile
}


END {
}
